@@ -6,7 +6,7 @@ import os
 
 class S3List:
 
-    def __init__(self, bucket, s3_client=None):
+    def __init__(self, bucket, s3_client=None, request_payer='bucketowner'):
         """
         From newtools 2.1.0 onwards, the list_folders method returns a set rather than a list.
         :param bucket: The s3 bucket to look for data in
@@ -14,6 +14,7 @@ class S3List:
         """
         self.s3_client = s3_client if s3_client else boto3.client('s3')
         self.bucket = bucket
+        self.request_payer = request_payer
 
     def list_folders(self, prefix=''):
         """
@@ -29,7 +30,8 @@ class S3List:
         paginator = self.s3_client.get_paginator("list_objects_v2")
         pages = paginator.paginate(Bucket=self.bucket,
                                    Delimiter='/',
-                                   Prefix=prefix)
+                                   Prefix=prefix,
+                                   RequestPayer=self.request_payer)
 
         for page in pages:
             if page.get('CommonPrefixes'):
@@ -47,7 +49,7 @@ class LoadPartitions:
 
     """
 
-    def __init__(self, bucket, s3_client=None):
+    def __init__(self, bucket, s3_client=None, request_payer='bucketowner'):
         """
         :param bucket: S3 bucket where the data is stored
         :param s3_client: optional param of pre initialised s3 client
@@ -55,6 +57,7 @@ class LoadPartitions:
 
         self.s3_client = s3_client
         self.s3_bucket = bucket
+        self.request_payer = request_payer
 
     def list_partitions(self, table=None, partition_depth=None, s3_path=None):
         """
@@ -73,7 +76,7 @@ class LoadPartitions:
 
             s3_path = table
 
-        list_files = S3List(self.s3_bucket, self.s3_client)
+        list_files = S3List(self.s3_bucket, self.s3_client, self.request_payer)
 
         partitions_list = list_files.list_folders(s3_path)
         partitions_tracked = 0
@@ -127,7 +130,7 @@ class LoadPartitions:
 
             athena_client.wait_for_completion()
             fm = FileDoggo(os.path.join(query.arguments["output_location"], "{}.txt".format(query.id)), mode='rb',
-                           compression=None, client=athena_s3_client)
+                           compression=None, client=athena_s3_client, request_payer=self.request_payer)
             with fm as f:
                 athena_list = f.read().decode().splitlines()
             athena_list = {'{table}/{partition}/'.format(table=s3_path, partition=partition) for partition in
