@@ -62,7 +62,7 @@ import hashlib
 from newtools.aws import S3Location
 from .sql_client import SqlClient
 from .athena import AthenaClient
-from newtools.doggo import DoggoLock, DoggoFileSystem, DynamoDogLock
+from newtools.doggo import DoggoLock, DoggoFileSystem, DynamoDogLock, FileDoggo, PandasDoggo
 
 # Set S3fsMixin for backwards compatibility
 S3fsMixin = DoggoFileSystem
@@ -382,7 +382,7 @@ class BaseCachedQuery(BaseCachedClass):
         with self._get_lock(output_file):
             if not self._exists(output_file):
                 # clean up any S3 files with the same prefix
-                for file in self.dfs.glob(output_file + "**"):
+                for file in self.dfs.glob(output_file + "**"):  # pragma: nocover
                     self.dfs.rm(file)
 
                 self._logger.info("Executing query to {0}".format(output_file))
@@ -395,15 +395,31 @@ class BaseCachedQuery(BaseCachedClass):
                 if self._redshift_checks and output_file.startswith("s3://"):
                     if not self.dfs.exists(output_file):
                         files = self.dfs.glob(output_file + "**")
-                        if len(files) == 0:
-                            raise ValueError("No file returned by the query. Does it contain an UNLOAD command?")
-                        elif len(files) > 1:
-                            raise ValueError(
-                                "More than one file produced by query. Is PARALLEL OFF set in your UNLOAD command?")
-                        else:
-                            self.dfs.mv(files[0], output_file)
+                        self._concatenate_files(output_file=output_file,
+                                                files=files)
         return output_file
 
+    def _concatenate_files(self, output_file, files, deleting_files=True):
+        if len(files) == 0:
+            raise ValueError("No file returned by the query. Does it contain an UNLOAD command?")
+        elif len(files) > 1:
+            self._logger.info(f"Concatenating {','.join([f for f in files])}")
+            with FileDoggo(output_file, 'wb', compression="gzip" if self._gzip else None) as outfile:
+                # Open each file to concatenate
+                for file_number, file in enumerate(files):
+                    # Write each line to the output file
+                    with FileDoggo(file, 'rb', compression="gzip" if self._gzip else None) as infile:
+                        if file_number != 0:  # Skip first line for the rest of files
+                            _ = infile.readline()
+                        shutil.copyfileobj(infile, outfile)
+            if deleting_files:
+                for file in files:
+                    self.dfs.rm(file)
+            else:
+                self._logger.info("Keeping the local file for unit test")
+        else:
+            self.dfs.mv(files[0], output_file)
+
     def _execute_query(self, **params):
         # Implemented by child
         raise NotImplementedError("BaseCachedClass cannot execute queries")
@@ -562,7 +578,8 @@ class CachedAthenaQuery(BaseCachedQuery):
         :param parameters: the parameters to apply
         :param file: the archive file path
         """
-        with self.dfs.open(file, 'wb') as f:  # FileDoggo does not support "wt" for S3 files
+        file_hash = file.replace('.sql', '') + f'_{int(time.time())}'
+        with self.dfs.open(f'{file_hash}.sql', 'wb') as f:  # FileDoggo does not support "wt" for S3 files
             f.write('-- Ran query on: {:%Y-%m-%d %H:%M:%S}\n'.format(datetime.datetime.now()).encode('UTF-8'))
             f.write('-- Parameters: {0}\n'.format(self._clean_dict(parameters)).encode('UTF-8'))
             f.write((logged_query + ';\n').encode('UTF-8'))
@@ -615,7 +632,6 @@ class CachedAthenaQuery(BaseCachedQuery):
         compression = 'gzip' if self._gzip else None
 
         for output_file in set(self._results.keys()):
-
             res = self._results.pop(output_file)
             actual_file = S3Location(self.cache_path).join(res.id + '.csv')
 
