@@ -163,4 +163,14 @@ sqlparse = get_sqlparse()
 
 # -----------------------------
 
+
+@import_wrapper(DummyClass("json_log_formatter"))
+def get_json_log_formatter():
+    import json_log_formatter
+    return json_log_formatter
+
+
+json_log_formatter = get_json_log_formatter()
+
 #  Add new optional imports to the bottom of this file together with the dummy class
+# -----------------------------
