@@ -4,7 +4,7 @@
 import sqlite3
 import os
 from time import time, sleep
-
+import pandas as pd
 from datetime import datetime, timedelta
 
 from .base_test import BaseTest
@@ -19,7 +19,7 @@ class TestCachedQuery(BaseTest):
 
     @classmethod
     def setUpClass(cls):
-        cls.s3_bucket = "s3://aws-athena-query-results-933373196108-us-west-2/{0}/".format(time())
+        cls.s3_bucket = "s3://newtools-tests/query-results/{0}/".format(time())
         super(TestCachedQuery, cls).setUpClass()
 
     @classmethod
@@ -97,6 +97,12 @@ class TestCachedQuery(BaseTest):
                           output_prefix="test_query",
                           )
 
+        # rerun the get_results to get full coverage
+        a1 = q.get_results(sql_file="test_select.sql",
+                           output_prefix="test_query",
+                          )
+        self.assertEqual(a, a1)
+
         # Validate the results still work without a database connection
         q2 = BaseCachedQuery(cache_path=self.tempdir,
                              sql_paths=[self.sql_path],
@@ -122,24 +128,22 @@ class TestCachedQuery(BaseTest):
         q = CachedPep249Query(self.sqlite_db,
                               cache_path=self.tempdir,
                               sql_paths=[self.sql_path],
-                              expiry_seconds=2,
+                              expiry_seconds=3,
                               gzip=False)
         self.set_timeouts(q)
 
-        # get to the point where a new two second period has started...
-        if int(int(time())) % 2 == 1:
+        # get to the point where a new three-second period has started...
+        if int(int(time())) % 3 == 1:
             sleep(1)
 
         path1 = q.get_results(sql_file="test_select.sql",
                               output_prefix="test_query",
                               )
 
-        sleep(1)
-
         path2 = q.get_results(sql_file="test_select.sql",
                               output_prefix="test_query",
                               )
-        sleep(2)
+        sleep(3)
 
         path3 = q.get_results(sql_file="test_select.sql",
                               output_prefix="test_query",
@@ -277,7 +281,8 @@ class TestCachedQuery(BaseTest):
         self.assertEqual(s, r)
 
         # check the archive.
-        query = open(os.path.join(self.tempdir, "athena_test.sql")).read()
+        file = DoggoFileSystem().glob(os.path.join(self.tempdir, "athena_test*.sql"))[0]
+        query = open(file).read()
 
         self.assertIn("-- Ran query on:", query)
         self.assertIn("-- Parameters: {'aws_region': 'us-west-2'", query)
@@ -336,7 +341,8 @@ class TestCachedQuery(BaseTest):
                       params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
 
         # check the archive.
-        with DoggoFileSystem().open(os.path.join(self.s3_bucket, "athena_test.sql"), "rb") as f:
+        file = DoggoFileSystem().glob(os.path.join(self.s3_bucket, "athena_test*.sql"))[0]
+        with DoggoFileSystem().open(file, "rb") as f:
             query = f.read().decode("UTF-8")
 
         self.assertIn("-- Ran query on:", query)
@@ -420,13 +426,19 @@ class TestCachedQuery(BaseTest):
                       output_prefix="athena_test",
                       replacement_dict={
                           "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"})
-        with self.assertRaisesRegex(ValueError,
-                                    "More than one file produced by query. Is PARALLEL OFF set in your UNLOAD"):
-            q.get_results(sql_file="athena_test.sql",
+
+        r = q.get_results(sql_file="athena_test.sql",
                           output_prefix="athena_test",
                           replacement_dict={
                               "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"})
 
+        # Get the output
+        output = PandasDoggo().load_csv(r, compression="gzip")
+
+        # check the results (should have double results)
+        self.assertEqual(output.to_csv(index=False),
+                         'dt,day\n{0:%Y-%m-%d},{0:%Y-%m-%d}\n{0:%Y-%m-%d},{0:%Y-%m-%d}\n'.format(datetime.utcnow()))
+
     def test_no_output_file(self):
         class MimicRedshiftQueryNone(CachedAthenaQuery):
             """
@@ -517,3 +529,19 @@ class TestCachedQuery(BaseTest):
         self.assertTrue(dfs.exists(r1))
         self.assertTrue(dfs.exists(r2))
         self.assertTrue(dfs.exists(r3))
+
+    def test_concatenating_files(self):
+        q2 = BaseCachedQuery(cache_path=self.tempdir,
+                             sql_paths=[self.sql_path],
+                             gzip=True)
+        output_file = os.path.join(self.tempdir, 'part.csv.gz')
+        files = [os.path.join(self.test_dir, 'concatenating_files', e) for e in ['part1.csv.gz', 'part2.csv.gz']]
+        pg = PandasDoggo()
+        # read raw data before being deleted
+        df_raw = pd.concat([pg.load_csv(file, compression='gzip') for file in files])
+        q2._concatenate_files(output_file=output_file,
+                              files=files,
+                              deleting_files=False)
+        df_new = pg.load_csv(output_file)
+        self.assertEqual(df_raw.col1.sum(), df_new.col1.sum())
+
