@@ -22,10 +22,11 @@ from newtools.optional_imports import numpy as np
 from newtools.optional_imports import pandas as pd
 from .base_test import BaseTest
 
-s3_bucket = "newtools-testing"
+s3_bucket = "newtools-tests"
 
 log_to_stdout("newtools", level=logging.DEBUG)
 
+
 class TestDoggos(unittest.TestCase):
 
     @classmethod
@@ -257,18 +258,41 @@ class TestDoggos(unittest.TestCase):
         expected_df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
                                                4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
                                     'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
-        pth = S3Location('newtools-testing').join('generic', 'email_test.csv')
+        pth = S3Location('newtools-tests').join('generic', 'email_test.csv')
         session = boto3.Session()
         fh = PandasDoggo(boto_session=session)
         df = fh.load(pth)
         pd.testing.assert_frame_equal(df, expected_df)
 
+    def test_read_csv_s3_request_payer_fail(self):
+        """try to read a csv from s3 with request_payer permissions on the bucket and 'requester' not set"""
+        pth = S3Location('newtools-test-request-payer').join('generic', 'email_test.csv')
+        session = boto3.Session()
+        fh = PandasDoggo(boto_session=session)
+
+        with self.assertRaises(Exception) as err:
+            fh.load(pth)
+
+        self.assertEqual(err.exception.args[0], 'An error occurred (403) when calling the HeadObject operation: Forbidden')
+
+    def test_read_csv_s3_request_payer(self):
+        """try to read a csv from s3 with request_payer permissions on the bucket and 'requester' set in Doggo"""
+        expected_df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
+                                               4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
+                                    'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
+        pth = S3Location('newtools-test-request-payer').join('generic', 'email_test.csv')
+        session = boto3.Session()
+        fh = PandasDoggo(boto_session=session)
+
+        df = fh.load(pth, request_payer='requester')
+        pd.testing.assert_frame_equal(df, expected_df)
+
     def test_write_csv_s3(self):
         df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
                                       4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
                            'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
-        pth = S3Location('newtools-testing').join('generic', 'email_test_copy.csv')
-        expected_pth = S3Location('newtools-testing').join('generic', 'email_test.csv')
+        pth = S3Location('newtools-tests').join('generic', 'email_test_copy.csv')
+        expected_pth = S3Location('newtools-tests').join('generic', 'email_test.csv')
         fh = PandasDoggo()
         fh.save(df, pth, index=None)
         with FileDoggo(pth) as p, FileDoggo(expected_pth) as p2:
@@ -282,7 +306,7 @@ class TestDoggos(unittest.TestCase):
         df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
                                       4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
                            'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
-        pth = S3Location('newtools-testing').join('generic', 'email_test_copy.csv.gz')
+        pth = S3Location('newtools-tests').join('generic', 'email_test_copy.csv.gz')
 
         fh = PandasDoggo()
 
@@ -298,7 +322,7 @@ class TestDoggos(unittest.TestCase):
         """read a parquet from s3"""
         fh = PandasDoggo()
 
-        df_s3 = fh.load_parquet('s3://07092018pqtest/data.parquet')
+        df_s3 = fh.load_parquet('s3://newtools-tests/07092018pqtest/data.parquet')
 
         pth_local = os.path.join(self.base_path, 'parquet', 'data.parquet')
         df_l = fh.load_parquet(pth_local)
@@ -310,9 +334,9 @@ class TestDoggos(unittest.TestCase):
         pth_local = os.path.join(self.base_path, 'parquet', 'data.parquet')
         df_l = fh.load_parquet(pth_local)
         s3 = boto3.resource('s3')
-        obj = s3.Object('07092018pqtest', 'write.parquet')
+        obj = s3.Object('newtools-tests', '07092018pqtest/write.parquet')
         obj.delete()  # just in case
-        fh.save(df_l, 's3://07092018pqtest/write.parquet')
+        fh.save(df_l, 's3://newtools-tests/07092018pqtest/write.parquet')
 
         obj.load()  # checks that it was written
         obj.delete()
@@ -321,7 +345,7 @@ class TestDoggos(unittest.TestCase):
         df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
                                       4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
                            'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
-        pth = S3Location('newtools-testing').join('generic', 'email_test_copy.parquet')
+        pth = S3Location('newtools-tests').join('generic', 'email_test_copy.parquet')
 
         fh = PandasDoggo()
 
@@ -405,8 +429,9 @@ class TestDoggoFileSystem(BaseTest):
         testdir = dfs.join(root, str(random()))
         file_1 = dfs.join(testdir, "temp_1.txt")
         dir_local_1 = testdir + '/'
-        dir_s3 = S3Location('newtools-testing').join('dfs/')
-
+        dir_s3 = S3Location('newtools-tests').join('dfs/')
+        if dfs.exists(dir_s3):
+            dfs.rm(dir_s3, recursive=True)
         with dfs.open(file_1, "wb") as f:
             f.write(b"woof")
 
@@ -427,10 +452,10 @@ class TestDoggoFileSystem(BaseTest):
         self.assertEqual(len(dfs.ls(os.path.join(dir_local_1, 'totallyfakefolder'))), 0)
         self.assertEqual(len(dfs.ls(os.path.join(dir_local_1, 'totallyfakefolder'), recursive=True)), 0)
 
-        self.assertEqual(dfs.ls(dir_s3), [S3Location('s3://newtools-testing/dfs/temp_1.txt')])
+        self.assertEqual(dfs.ls(dir_s3), [S3Location('s3://newtools-tests/dfs/temp_1.txt')])
 
         self.assertEqual(dfs.ls(S3Location(dir_s3), recursive=True),
-                         [S3Location('s3://newtools-testing/dfs/temp_1.txt')])
+                         [S3Location('s3://newtools-tests/dfs/temp_1.txt')])
 
     def test_mixed_local_s3(self):
         dfs = DoggoFileSystem()
@@ -441,13 +466,15 @@ class TestDoggoFileSystem(BaseTest):
         file_2 = dfs.join(testdir, "tests", "temp_2.txt")
         dir_local_1 = testdir + '/'
         dir_local_2 = dfs.join(root, str(random())) + '/'
-        dir_s3 = S3Location('newtools-testing').join('dfs')
+        dir_s3 = S3Location('newtools-tests').join('dfs2')
         file_3 = dfs.join(dir_local_2, "temp_1.txt")
         file_4 = dfs.join(dir_local_2, "tests", "temp_2.txt")
-        s3_loc_1 = S3Location('newtools-testing').join('dfs', 'temp_1.txt')
-        s3_loc_2 = S3Location('newtools-testing').join('dfs', 'temp_2.txt')
-        dfs.rm(s3_loc_1)
-        dfs.rm(s3_loc_2)
+        s3_loc_1 = S3Location('newtools-tests').join('dfs2', 'temp_1.txt')
+        s3_loc_2 = S3Location('newtools-tests').join('dfs2', 'temp_2.txt')
+        if dfs.exists(s3_loc_1):
+            dfs.rm(s3_loc_1)
+        if dfs.exists(s3_loc_2):
+            dfs.rm(s3_loc_2)
 
         with self.assertRaises(FileNotFoundError):
             dfs.cp(s3_loc_1, s3_loc_2)
@@ -514,14 +541,20 @@ class TestDoggoFileSystem(BaseTest):
         self.assertFalse(dfs.exists(file_3))
         self.assertTrue(dfs.exists(s3_loc_1))
 
-        dfs.rm(s3_loc_1)
-        dfs.rm(s3_loc_2)
+        if dfs.exists(s3_loc_1):
+            dfs.rm(s3_loc_1)
+        if dfs.exists(s3_loc_2):
+            dfs.rm(s3_loc_2)
 
     def test_s3(self):
-        self._test(S3Location("s3://07092018pqtest/fs/"))
+        self._test(S3Location("s3://newtools-tests/07092018pqtest/fs/"))
 
         dfs = DoggoFileSystem()
-        self.assertEqual(dfs.split("s3://07092018pqtest/temp.txt"), ("s3://07092018pqtest/", "temp.txt"))
+        self.assertEqual(dfs.split("s3://newtools-tests/07092018pqtest/temp.txt"),
+                         ("s3://newtools-tests/07092018pqtest", "temp.txt"))
+        # for full coverage
+        self.assertEqual(dfs.split("s3://newtools-tests/temp.txt"),
+                         ("s3://newtools-tests/", "temp.txt"))
 
     def test_file(self):
         self._test(self.tempdir)
@@ -594,7 +627,7 @@ class BaseLockTest(BaseTest):
 
 
 class TestDoggoLockS3(BaseLockTest):
-    tempdir = 's3://newtools-tests-data/locks/'
+    tempdir = 's3://newtools-tests/locks/'
     LockClass = DoggoLock
 
 
@@ -762,7 +795,7 @@ class TestDoggoFileSystem_2(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.base_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'test_data', 'doggofilesystem_tests')
-        cls.bucket = "newtools-testing"
+        cls.bucket = "newtools-tests"
         cls.prefix = 'doggofilesystem_tests'
         cls.path = S3Location(bucket=cls.bucket, key=cls.prefix)
         cls.dfs = DoggoFileSystem()
@@ -771,7 +804,8 @@ class TestDoggoFileSystem_2(unittest.TestCase):
             'doggofilesystem_tests/pixel/source_partition=pix.pub/date=2019-01-01/l_tag=dativa-health-check/2019-01-01_094118.631787.parquet',
             'doggofilesystem_tests/pixel/source_partition=pix.pub/date=2019-01-01/l_tag=food-network-kitchen-app-across-channel/2019-01-01_094117.723581.parquet',
             'doggofilesystem_tests/pixel/source_partition=pixels.dativa.com/date=2021-01-01/l_tag=dativa-health-check/2021-01-01_094118.631787.parquet',
-            'doggofilesystem_tests/pixel/source_partition=pixels.dativa.com/date=2021-01-01/l_tag=food-network-kitchen-app-across-channel/2021-01-01_094117.723581.parquet']
+            'doggofilesystem_tests/pixel/source_partition=pixels.dativa.com/date=2021-01-01/l_tag=food-network-kitchen-app-across-channel/2021-01-01_094117.723581.parquet',
+            'doggofilesystem_tests/test1.txt']
 
     @classmethod
     def tearDownClass(cls):
@@ -828,5 +862,6 @@ class TestDoggoFileSystem_2(unittest.TestCase):
         self.assertEqual(len(self.dfs.ls(self.base_path, recursive=True)), len(self.file_list))
         self.assertEqual(self.dfs.ls(self.base_path + f'/{random()}/', recursive=True), [])
 
-        self.assertEqual(len(self.dfs.ls(self.base_path)), 2)
+        self.assertEqual(len(self.dfs.ls(self.base_path)), 3)
         self.assertEqual(len(self.dfs.ls(self.base_path + f"{random()}")), 0)
+
