@@ -4,13 +4,13 @@ from newtools.db import AthenaClient
 
 
 class TestLoadPartitions(unittest.TestCase):
-    bucket = "newtools-tests-data"
+    bucket = "newtools-tests"
     tablename = "load_partition_test_data"
-    region = "eu-west-1"
+    region = "us-west-2"
     prefix = "load_partition_test_data/"
-    database = "test_database"
-    output_location = "s3://aws-athena-query-results-933373196108-eu-west-1/"
-    source_file = "s3://newtools-tests-data/load_partition_test_data/"
+    database = "test_db"
+    output_location = "s3://newtools-tests/query_results/"
+    source_file = "s3://newtools-tests/load_partition_test_data/"
     athena_client = None
 
     @classmethod
@@ -71,21 +71,25 @@ class TestLoadPartitions(unittest.TestCase):
         with self.assertRaises(ValueError):
             self.load_partitions.list_partitions()
 
+    def test_list_partiton_empty(self):
+        s3_path = 'never_exist_folder'
+        self.assertEqual(self.load_partitions.list_partitions(s3_path=s3_path), set())
+
     def test_get_sql(self):
         sql_query_list = [
-            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory/' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory_1/' PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/some_more_directory/'"]
+            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests/load_partition_test_data/year=2019/month=02/some_more_directory/' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests/load_partition_test_data/year=2019/month=0:2/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory_1/' PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=02/some_more_directory/'"]
         test_sql_query_list = self.load_partitions.get_sql('load_partition_test_data')
         self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
                               [x.strip() for x in test_sql_query_list[0].split('PARTITION')])
 
     def test_get_sql_full_file_names(self):
         sql_query_list = [
-            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory_1' PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/some_more_directory'"]
-        file_names = ['s3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory/file1.parquet.sz',
-                      's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory/file2.parquet.sz',
-                      's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory/file3.parquet.sz',
-                      's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory_1/file4.parquet.sz',
-                      's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/some_more_directory/file5.parquet.sz']
+            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests/load_partition_test_data/year=2019/month=02/some_more_directory' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests/load_partition_test_data/year=2019/month=0:2/some_more_directory' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory_1' PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=02/some_more_directory'"]
+        file_names = ['s3://newtools-tests/load_partition_test_data/year=2019/month=02/some_more_directory/file1.parquet.sz',
+                      's3://newtools-tests/load_partition_test_data/year=2019/month=0:2/some_more_directory/file2.parquet.sz',
+                      's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory/file3.parquet.sz',
+                      's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory_1/file4.parquet.sz',
+                      's3://newtools-tests/load_partition_test_data/year=2020/month=02/some_more_directory/file5.parquet.sz']
         test_sql_query_list = self.load_partitions.get_sql_from_file_names('load_partition_test_data', file_names)
         self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
                               [x.strip() for x in test_sql_query_list[0].split('PARTITION')])
@@ -96,7 +100,7 @@ class TestLoadPartitions(unittest.TestCase):
                            'load_partition_test_data/year=2020/month=01/some_more_directory/'}
 
         sql_query_list = [
-            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory/' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory/'"]
+            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests/load_partition_test_data/year=2019/month=02/some_more_directory/' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests/load_partition_test_data/year=2019/month=0:2/some_more_directory/' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=01/some_more_directory/'"]
 
         sql_query_list_test = self.load_partitions.generate_sql('load_partition_test_data', partitions_list)
         self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
@@ -109,7 +113,7 @@ class TestLoadPartitions(unittest.TestCase):
                            'load_partition_test_data/year=2020/month=02/'}
 
         sql_query_list = [
-            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/'"]
+            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests/load_partition_test_data/year=2020/month=02/'"]
 
         sql_query_list_test = self.load_partitions.generate_sql('load_partition_test_data', partitions_list,
                                                                 athena_client=self.athena_client,
